@@ -1,4 +1,3 @@
-/* $Xorg: StBytes.c,v 1.4 2001/02/09 02:03:36 xorgcvs Exp $ */
 /*
 
 Copyright 1986, 1998  The Open Group
@@ -24,7 +23,6 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/lib/X11/StBytes.c,v 1.4 2001/12/14 19:54:07 dawes Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -51,9 +49,9 @@ XRotateBuffers (
     /* XRotateWindowProperties wants a non-const Atom*, but it doesn't
      * modify it, so this is safe.
      */
-    return XRotateWindowProperties(dpy, RootWindow(dpy, 0), n_to_atom, 8, rotate);
+    return XRotateWindowProperties(dpy, RootWindow(dpy, 0), (Atom *)n_to_atom, 8, rotate);
 }
-    
+
 char *XFetchBuffer (
     register Display *dpy,
     int *nbytes,
@@ -67,8 +65,8 @@ char *XFetchBuffer (
     *nbytes = 0;
     if ((buffer < 0) || (buffer > 7)) return (NULL);
 /* XXX should be (sizeof (maxint) - 1)/4 */
-    if (XGetWindowProperty(dpy, RootWindow(dpy, 0), n_to_atom[buffer], 
-	0L, 10000000L, False, XA_STRING, 
+    if (XGetWindowProperty(dpy, RootWindow(dpy, 0), n_to_atom[buffer],
+	0L, 10000000L, False, XA_STRING,
 	&actual_type, &actual_format, &nitems, &leftover, &data) != Success) {
 	return (NULL);
 	}
@@ -95,7 +93,7 @@ XStoreBuffer (
     register int buffer)
 {
     if ((buffer < 0) || (buffer > 7)) return 0;
-    return XChangeProperty(dpy, RootWindow(dpy, 0), n_to_atom[buffer], 
+    return XChangeProperty(dpy, RootWindow(dpy, 0), n_to_atom[buffer],
 	XA_STRING, 8, PropModeReplace, (unsigned char *) bytes, nbytes);
 }
 
